#!/usr/bin/env python

"""A library that provides a Python interface to the Status.io API"""
from __future__ import absolute_import

__author__ = 'hello@status.io'
__version__ = '0.5'

import json                                 # noqa

from .api import Api                        # noqa
